@@ -1,3 +1,17 @@
+# Copyright 2021 The casbin Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import threading
 import time
 
@@ -48,9 +62,7 @@ class SyncedEnforcer:
         if self.is_auto_loading_running():
             return
         self._auto_loading.value = True
-        self._auto_loading_thread = threading.Thread(
-            target=self._auto_load_policy, args=[interval], daemon=True
-        )
+        self._auto_loading_thread = threading.Thread(target=self._auto_load_policy, args=[interval], daemon=True)
         self._auto_loading_thread.start()
 
     def stop_auto_load_policy(self):
@@ -221,9 +233,7 @@ class SyncedEnforcer:
     def get_filtered_named_grouping_policy(self, ptype, field_index, *field_values):
         """gets all the role inheritance rules in the policy, field filters can be specified."""
         with self._rl:
-            return self._e.get_filtered_named_grouping_policy(
-                ptype, field_index, *field_values
-            )
+            return self._e.get_filtered_named_grouping_policy(ptype, field_index, *field_values)
 
     def has_policy(self, *params):
         """determines whether an authorization rule exists."""
@@ -269,9 +279,7 @@ class SyncedEnforcer:
     def remove_filtered_named_policy(self, ptype, field_index, *field_values):
         """removes an authorization rule from the current named policy, field filters can be specified."""
         with self._wl:
-            return self._e.remove_filtered_named_policy(
-                ptype, field_index, *field_values
-            )
+            return self._e.remove_filtered_named_policy(ptype, field_index, *field_values)
 
     def has_grouping_policy(self, *params):
         """determines whether a role inheritance rule exists."""
@@ -317,9 +325,7 @@ class SyncedEnforcer:
     def remove_filtered_named_grouping_policy(self, ptype, field_index, *field_values):
         """removes a role inheritance rule from the current named policy, field filters can be specified."""
         with self._wl:
-            return self._e.remove_filtered_named_grouping_policy(
-                ptype, field_index, *field_values
-            )
+            return self._e.remove_filtered_named_grouping_policy(ptype, field_index, *field_values)
 
     def add_function(self, name, func):
         """adds a customized function."""
@@ -456,8 +462,23 @@ class SyncedEnforcer:
         But get_implicit_permissions_for_user("alice") will get: [["admin", "data1", "read"], ["alice", "data2", "read"]].
         """
         with self._rl:
-            return self._e.get_implicit_permissions_for_user(
-                user, *domain, filter_policy_dom=filter_policy_dom
+            return self._e.get_implicit_permissions_for_user(user, *domain, filter_policy_dom=filter_policy_dom)
+
+    def get_named_implicit_permissions_for_user(self, ptype, user, *domain, filter_policy_dom=True):
+        """
+        gets implicit permissions for a user or role by named policy.
+        Compared to get_permissions_for_user(), this function retrieves permissions for inherited roles.
+        For example:
+        p, admin, data1, read
+        p, alice, data2, read
+        g, alice, admin
+
+        get_permissions_for_user("alice") can only get: [["alice", "data2", "read"]].
+        But get_implicit_permissions_for_user("alice") will get: [["admin", "data1", "read"], ["alice", "data2", "read"]].
+        """
+        with self._rl:
+            return self._e.get_named_implicit_permissions_for_user(
+                ptype, user, *domain, filter_policy_dom=filter_policy_dom
             )
 
     def get_implicit_users_for_permission(self, *permission):
@@ -501,6 +522,11 @@ class SyncedEnforcer:
         with self._rl:
             return self._e.get_permissions_for_user_in_domain(user, domain)
 
+    def get_named_permissions_for_user_in_domain(self, ptype, user, domain):
+        """gets permissions for a user or role by named policy inside domain."""
+        with self._rl:
+            return self._e.get_named_permissions_for_user_in_domain(ptype, user, domain)
+
     def enable_auto_build_role_links(self, auto_build_role_links):
         """controls whether to rebuild the role inheritance relations when a role is added or deleted."""
         with self._wl:
@@ -588,9 +614,7 @@ class SyncedEnforcer:
             return self._e.remove_named_grouping_policies(ptype, rules)
 
     def build_incremental_role_links(self, op, ptype, rules):
-        self.get_model().build_incremental_role_links(
-            self.get_role_manager(), op, "g", ptype, rules
-        )
+        self.get_model().build_incremental_role_links(self.get_role_manager(), op, "g", ptype, rules)
 
     def new_enforce_context(self, suffix: str) -> "EnforceContext":
         return self._e.new_enforce_context(suffix)
