@@ -1,3 +1,17 @@
+# Copyright 2021 The casbin Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from unittest import TestCase
 from casbin.rbac import default_role_manager
 from casbin.util import regex_match_func
@@ -81,9 +95,7 @@ class TestRoleManager(TestCase):
 
         rm.clear()
 
-        match_fn = (
-            lambda name1, name2: True if re.match("^" + name2 + "$", name1) else False
-        )
+        match_fn = lambda name1, name2: True if re.match("^" + name2 + "$", name1) else False
 
         rm.add_matching_func(match_fn)
 
@@ -111,9 +123,7 @@ class TestRoleManager(TestCase):
         self.assertTrue(rm.has_link("g2", "any_group"))
 
         self.assertEqual(sorted(rm.get_roles("u1")), sorted(["g1", "any_user"]))
-        self.assertEqual(
-            sorted(rm.get_roles("u2")), sorted(["g2", "g1", r"g\d+", "any_user"])
-        )
+        self.assertEqual(sorted(rm.get_roles("u2")), sorted(["g2", "g1", r"g\d+", "any_user"]))
         self.assertEqual(rm.get_roles(r"u\d+"), ["any_user"])
         self.assertEqual(rm.get_roles("u3"), ["any_user"])
         self.assertEqual(rm.get_roles("g1"), ["any_group"])
@@ -293,9 +303,7 @@ class TestDomainManager(TestRoleManager):
         self.assertTrue(rm.has_link("u4", "admin", "domain2"))
 
         rm.clear()
-        match_fn = (
-            lambda name1, name2: True if re.match("^" + name2 + "$", name1) else False
-        )
+        match_fn = lambda name1, name2: True if re.match("^" + name2 + "$", name1) else False
 
         rm.add_domain_matching_func(match_fn)
         rm.add_link("alice", "user", ".*")
